package com.qmth.eds.api;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.eds.contant.SystemConstant;
import com.qmth.eds.entity.ExamScheduleTask;
import com.qmth.eds.service.ExamScheduleTaskService;
import com.qmth.eds.util.Result;
import com.qmth.eds.util.ResultUtil;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;

@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/exam_schedule_task")
@Aac(auth = BOOL.FALSE)
public class ExamScheduleTaskController {

    @Resource
    private ExamScheduleTaskService examScheduleTaskService;

    /**
     * 查询
     *
     * @param schoolId   学校ID
     * @param semesterId 学期ID
     * @param examTypeId 考试类型ID
     * @param startTime  定时任务开始时间
     * @param endTime    定时任务结束时间
     * @param pageNumber 分页参数
     * @param pageSize   分页参数
     */
    @ApiOperation(value = "查询")
    @PostMapping("/page")
    public Result page(@RequestParam(value = "schoolId", required = false) Long schoolId,
                       @RequestParam(value = "semesterId", required = false) Long semesterId,
                       @RequestParam(value = "examTypeId", required = false) Long examTypeId,
                       @RequestParam(value = "startTime", required = false) Long startTime,
                       @RequestParam(value = "endTime", required = false) Long endTime,
                       @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                       @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(examScheduleTaskService.list(schoolId, semesterId, examTypeId, startTime, endTime, pageNumber, pageSize));
    }

    /**
     * 新增/修改
     *
     * @param examScheduleTask 定时任务信息对象
     */
    @ApiOperation(value = "新增/修改")
    @PostMapping("/save")
    public Result save(@ApiParam(value = "定时任务信息", required = true) @Valid @RequestBody ExamScheduleTask examScheduleTask, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        return ResultUtil.ok(examScheduleTaskService.saveTask(examScheduleTask));
    }
}
