package com.qmth.eds.api;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.eds.bean.params.LoginParam;
import com.qmth.eds.bean.result.EditResult;
import com.qmth.eds.bean.result.LoginResult;
import com.qmth.eds.entity.SysUser;
import com.qmth.eds.enums.AppSourceEnum;
import com.qmth.eds.enums.ExceptionResultEnum;
import com.qmth.eds.service.SysUserService;
import com.qmth.eds.service.TeachcloudCommonService;
import com.qmth.eds.util.Result;
import com.qmth.eds.util.ResultUtil;
import com.qmth.eds.util.ServletUtil;
import io.swagger.annotations.*;
import org.apache.commons.lang3.StringUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.security.NoSuchAlgorithmException;
import java.util.List;

/**
 * 系统公共Controller
 */
@Api(tags = "系统Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/common")
public class SysController {
    @Resource
    SysUserService sysUserService;

    @Resource
    TeachcloudCommonService teachcloudCommonService;

    /**
     * 登录
     *
     * @param login         登录参数
     * @param bindingResult 错误
     */
    @ApiOperation(value = "登录")
    @PostMapping("/login")
    @ApiResponses({@ApiResponse(code = 200, message = "用户信息", response = LoginResult.class)})
    @Aac(auth = BOOL.FALSE)
    public Result login(@ApiParam(value = "用户信息", required = true) @Valid @RequestBody LoginParam login, BindingResult bindingResult) throws NoSuchAlgorithmException {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }

        // 账号密码登录
        String loginName = login.getLoginName();
        String password = login.getPassword();
        // 非空校验
        if (StringUtils.isBlank(loginName)) {
            throw ExceptionResultEnum.ERROR.exception("用户名不能为空");
        }
        if (StringUtils.isBlank(password)) {
            throw ExceptionResultEnum.ERROR.exception("密码不能为空");
        }
        QueryWrapper<SysUser> wrapper = new QueryWrapper<>();
        wrapper.lambda().and(w -> w.eq(SysUser::getLoginName, loginName).or().eq(SysUser::getCode, loginName));
        List<SysUser> userList = sysUserService.list(wrapper);
        //用户不存在
        if (userList == null || userList.isEmpty()) {
            throw ExceptionResultEnum.ERROR.exception("用户不存在");
        }
        if (userList.size() > 1) {
            throw ExceptionResultEnum.ERROR.exception("查出多个用户");
        }
        SysUser sysUser = userList.get(0);
        if (!sysUser.getEnable()) {
            throw ExceptionResultEnum.ERROR.exception("用户被禁用");
        }
        if (!password.equals(userList.get(0).getPassword())) {
            throw ExceptionResultEnum.ERROR.exception("密码错误");
        }
        LoginResult loginResult = teachcloudCommonService.login(login.getPassword(), sysUser, AppSourceEnum.SYSTEM);
        return ResultUtil.ok(loginResult);
    }

    /**
     * 登出
     */
    @ApiOperation(value = "登出")
    @PostMapping("/logout")
    @ApiResponses({@ApiResponse(code = 200, message = "返回信息", response = EditResult.class)})
    public Result logout() throws NoSuchAlgorithmException {
        SysUser sysUser = (SysUser) ServletUtil.getRequestUser();
        teachcloudCommonService.removeUserInfo(sysUser.getId(), false);
        return ResultUtil.ok();
    }

}
