package com.qmth.eds.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.qmth.eds.config.DictionaryConfig;
import com.qmth.eds.entity.ExamSyncStudentTemp;
import com.qmth.eds.enums.ExceptionResultEnum;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 武汉大学工具类
 */
@Component
public class WuhanUniversityUtils {

    @Resource
    private DictionaryConfig dictionaryConfig;

    /**
     * 获取token
     */
    public String getAccessToken() {
        String appKey = dictionaryConfig.whuDomain().getAppKey();
        String appSecret = dictionaryConfig.whuDomain().getAppSecret();
        String tokenUrl = dictionaryConfig.whuDomain().getTokenUrl();
        validUrl(appKey, appSecret, tokenUrl);
        try {
            //参数
            Map<String, String> paramMap = new HashMap<>();
            paramMap.put("appKey", appKey);
            paramMap.put("appSecret", appSecret);

            String result = HttpKit.sendPost(tokenUrl, paramMap, null);
            JSONObject jsonResult = JSON.parseObject(result);
            if (jsonResult.containsKey("status") && "success".equals(jsonResult.getString("status"))) {
                String token = jsonResult.getString("token");
                JSONObject jsonToken = JSON.parseObject(token);
                if (jsonToken.containsKey("accessToken")) {
                    return jsonToken.getString("accessToken");
                }
            }
            return null;
        } catch (Exception e) {
            throw ExceptionResultEnum.ERROR.exception(e.getMessage());
        }
    }

    /**
     * 获取考务数据
     */
    public List<ExamSyncStudentTemp> getKwData(String token) {
        String kwUrl = dictionaryConfig.whuDomain().getKwUrl();
        validUrl(kwUrl);
        try {
            //参数
            Map<String, String> headerMap = new HashMap<>();
            headerMap.put("Authorization", "Bearer " + token);

            String result = HttpKit.sendGet(kwUrl, null, headerMap);
            List<ExamSyncStudentTemp> examSyncStudentTemps = null;
            JSONObject jsonObject = JSON.parseObject(result);
            if (jsonObject.containsKey("status") && jsonObject.getBoolean("status")) {
                String data = jsonObject.getString("data");
                examSyncStudentTemps = JSONObject.parseArray(data, ExamSyncStudentTemp.class);
            }
            return examSyncStudentTemps;
//            return listTemps();
        } catch (Exception e) {
            throw ExceptionResultEnum.ERROR.exception(e.getMessage());
        }
    }

    /**
     * 校验url是否配置
     *
     * @param urls URL数组
     */
    private void validUrl(String... urls) {
        if (StringUtils.isAnyBlank(urls)) {
            throw ExceptionResultEnum.ERROR.exception("接口参数未配置");
        }
    }

    private List<ExamSyncStudentTemp> listTemps() {
        List<ExamSyncStudentTemp> examSyncStudentTemps = new ArrayList<>();
        for (int i = 0; i < 4; i++) {
            ExamSyncStudentTemp examSyncStudentTemp = new ExamSyncStudentTemp();
            examSyncStudentTemp.setXnm("100" + i);
            examSyncStudentTemp.setXqm("200" + i);
            examSyncStudentTemp.setJxbId("300" + i);
            examSyncStudentTemp.setJxbmc("教学班" + i);
            examSyncStudentTemp.setKch("400" + i);
            examSyncStudentTemp.setKcmc("课程" + i);
            examSyncStudentTemp.setJgh("500" + i);
            examSyncStudentTemp.setXm("姓名" + i);
            examSyncStudentTemp.setKkbm("开课学院" + i);
            examSyncStudentTemp.setXf("35");
            examSyncStudentTemp.setXh("100000100" + i);
            examSyncStudentTemp.setXsxm("学生" + i);
            examSyncStudentTemp.setJgmc("机构" + i);
            examSyncStudentTemp.setZymc("专业" + i);
            examSyncStudentTemp.setCxbj("0");
            examSyncStudentTemp.setNjdmId("年级" + i);
            examSyncStudentTemp.setZwh("1" + i);
            examSyncStudentTemp.setCdmc("考场" + i);
            examSyncStudentTemp.setKsbz("无");
            examSyncStudentTemps.add(examSyncStudentTemp);
        }
        return examSyncStudentTemps;
    }
}
